.. _annotation_ref:

Time series annotation
======================

The :mod:`aeon.annotation` module contains algorithms and tools
for time series annotation tasks, like anomaly/outlier detection,
and time series segmentation.

Time Series Segmentation
------------------------

.. currentmodule:: aeon.annotation.clasp

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    ClaSPSegmentation

.. currentmodule:: aeon.annotation.eagglo

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    EAgglo

.. currentmodule:: aeon.annotation.hmm_learn.gaussian

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    GaussianHMM

.. currentmodule:: aeon.annotation.hmm_learn.gmm

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    GMMHMM

.. currentmodule:: aeon.annotation.ggs

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    GreedyGaussianSegmentation

.. currentmodule:: aeon.annotation.hmm

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    HMM

.. currentmodule:: aeon.annotation.igts

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    InformationGainSegmentation

.. currentmodule:: aeon.annotation.hmm_learn.poisson

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    PoissonHMM

.. currentmodule:: aeon.annotation.stray

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    STRAY

Adapters
--------

.. currentmodule:: aeon.annotation.adapters

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    PyODAnnotator

Data Generation
---------------

.. automodule:: aeon.annotation.datagen
    :no-members:
    :no-inherited-members:
